# Journal des modifications

Ce fichier est généré automatiquement après chaque modification du dépôt. 
Les numéros indiqués correspondent aux [versions taggées](https://gitlab.com/canarduck/pays/tags).

## Prochaine version

### ✍ Changements

* Refacto api privée Countries.

## v0.1.3 (2018-02-15)

### ★ Nouveautés

* Generateur de country.

### ✍ Changements

* Mise à jour de la documentation.

## v0.1.2 (2018-02-14)

### ✍ Changements

* Renommage des classes en anglais.

### ⚔ Correctifs

* Génération eng.json.

## v0.1.0 (2018-02-14)

### ★ Nouveautés

* Génération des fichiers et interface de base.

### ⚔ Correctifs

* Dev-requirements.

